@@ -42,7 +42,7 @@ sub cmp {
     return undef; # currently we don't provide comparison
 }
 
-sub type_in_english {
+sub english {
     my ($self, $schema, $opt) = @_;
     $schema = $self->validator->normalize_schema($schema)
         unless ref($schema) eq 'HASH';
@@ -56,7 +56,7 @@ sub type_in_english {
                     $ss = $self->validator->normalize_schema($ss)
                         unless ref($ss) eq 'HASH';
                     my $th = $self->validator->get_type_handler($ss->{type});
-                    push @e, $th->type_in_english($ss, $opt);
+                    push @e, $th->english($ss, $opt);
                 }
                 return join " as well as ", map { "($_)" } @e;
             }
@@ -114,4 +114,5 @@ under the same terms as Perl itself.
 =cut
 
 __PACKAGE__->meta->make_immutable;
+no Moose;
 1;
